.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.context
============

Module: :mod:`core.context`
---------------------------
Inheritance diagram for ``zmq.core.context``:

.. inheritance-diagram:: zmq.core.context 
   :parts: 3

.. automodule:: zmq.core.context

.. currentmodule:: zmq.core.context

:class:`Context`
----------------


.. autoclass:: Context
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

